<!-- markdownlint-disable -->

<a href="..\..\qtstrap\widgets\line_widgets.py#L0"><img align="right" style="float:right;" src="https://img.shields.io/badge/-source-cccccc?style=flat-square"></a>

# <kbd>module</kbd> `widgets.line_widgets`




**Global Variables**
---------------
- **PYQT6**
- **PYQT5**
- **PYSIDE2**
- **PYSIDE6**


---

<a href="..\..\qtstrap\widgets\line_widgets.py#L4"><img align="right" style="float:right;" src="https://img.shields.io/badge/-source-cccccc?style=flat-square"></a>

## <kbd>class</kbd> `VLine`




<a href="..\..\qtstrap\widgets\line_widgets.py#L5"><img align="right" style="float:right;" src="https://img.shields.io/badge/-source-cccccc?style=flat-square"></a>

### <kbd>method</kbd> `VLine.__init__`

```python
__init__(parent=None, line_width=1)
```









---

<a href="..\..\qtstrap\widgets\line_widgets.py#L13"><img align="right" style="float:right;" src="https://img.shields.io/badge/-source-cccccc?style=flat-square"></a>

## <kbd>class</kbd> `HLine`




<a href="..\..\qtstrap\widgets\line_widgets.py#L14"><img align="right" style="float:right;" src="https://img.shields.io/badge/-source-cccccc?style=flat-square"></a>

### <kbd>method</kbd> `HLine.__init__`

```python
__init__(parent=None, line_width=1)
```











---

_This file was automatically generated via [lazydocs](https://github.com/ml-tooling/lazydocs)._
